@@ -16,6 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
+#include "command.h"
 #include "edit.h"
 #include "find.h"
 #include "general.h"
@@ -504,6 +505,7 @@ gboolean prompt_close(TEXTWND *ptw)
 		switch (message_box("Text maid",text,0,
 								_("Ϥ"),_(""),_("󥻥"),NULL)) {
 			case 0:
+				command_save(NULL,0,NULL);
 				if (!ptw->edit)
 					break;
 			case 2:
