@@ -228,7 +228,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 	gdk_gc_set_foreground(gc,ptw->color+1);
 	gdk_draw_rectangle(widget->window,gc,TRUE,event->area.x,event->area.y,
 										event->area.width,event->area.height);
-	if (ptw->grid) {
+	if (ptw->gline) {
 		/* å */
 		gdk_gc_set_foreground(gc,ptw->color+7);
 		for (x=ptw->fontsize-1;x<widget->allocation.width;x+=ptw->fontsize)
@@ -374,7 +374,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 				gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 												ptw->fontsize,ptw->fontsize*2);
 			}
-			gdk_gc_set_foreground(gc,ptw->color+2);
+			gdk_gc_set_foreground(gc,ptw->color+4);
 			if (p->next==NULL) {
 				/* եκǸ */
 				gdk_draw_arc(widget->window,gc,TRUE,
