@@ -83,6 +83,7 @@ GtkItemFactoryEntry menu_items[]={
 {N_("/(_S)"),                                   NULL,         NULL,            0,"<Branch>"},
 {N_("/(S)/(_F)..."),                        "<control>F", command_find,    0,"<Item>"},
 {N_("/(S)/򸡺(_N)"),                       "F3",         command_next,    0,"<Item>"},
+{N_("/(S)/դ򸡺(_B)"),                       "<shift>F3",  command_next,    1,"<Item>"},
 {N_("/(S)/ִ(_R)..."),                        "<control>H", command_replace, 0,"<Item>"},
 {N_("/ץ(_O)"),                             NULL,         NULL,            0,"<Branch>"},
 {N_("/ץ(O)/(_C)..."),                  NULL,         conf_dialog,     0,"<Item>"},
@@ -216,10 +217,6 @@ int main(int argc,char *argv[])
 								(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 				ftype[i].tab=8;
-			if (!profile_get_value(profile,section,"backup",
-								(gpointer)&ftype[i].backup,sizeof(gboolean),
-													PROFILE_VALUE_TYPE_BOOL))
-				ftype[i].backup=FALSE;
 			if (!profile_get_value(profile,section,"code",
 								(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -232,10 +229,6 @@ int main(int argc,char *argv[])
 								(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].eof=FALSE;
-			if (!profile_get_value(profile,section,"grid",
-								(gpointer)&ftype[i].grid,sizeof(gboolean),
-													PROFILE_VALUE_TYPE_BOOL))
-				ftype[i].grid=FALSE;
 			if (!profile_get_value(profile,section,"limit",
 								(gpointer)&ftype[i].limit,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -248,6 +241,10 @@ int main(int argc,char *argv[])
 								(gpointer)&ftype[i].space,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].space=FALSE;
+			if (!profile_get_value(profile,section,"gline",
+								(gpointer)&ftype[i].gline,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].gline=FALSE;
 			if (!profile_get_value(profile,section,"mline",
 								(gpointer)&ftype[i].mline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -289,14 +286,13 @@ int main(int argc,char *argv[])
 		ftype[1].ext=g_strdup("*");
 		ftype[0].margin=ftype[1].margin=80;
 		ftype[0].tab=ftype[1].tab=8;
-		ftype[0].backup=ftype[1].backup=FALSE;
 		ftype[0].code=ftype[1].code=FALSE;
 		ftype[0].crlf=ftype[1].crlf=FALSE;
 		ftype[0].eof=ftype[1].eof=FALSE;
-		ftype[0].grid=ftype[1].grid=FALSE;
 		ftype[0].limit=ftype[1].limit=FALSE;
 		ftype[0].overwrite=ftype[1].overwrite=FALSE;
 		ftype[0].space=ftype[1].space=FALSE;
+		ftype[0].gline=ftype[1].gline=FALSE;
 		ftype[0].mline=ftype[1].mline=FALSE;
 		ftype[0].uline=ftype[1].uline=FALSE;
 		ftype[0].vline=ftype[1].vline=FALSE;
@@ -489,9 +485,6 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"tab",
 								(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
-			profile_set_value(profile,section,"backup",
-								(gpointer)&ftype[i].backup,sizeof(gboolean),
-													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"code",
 								(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
@@ -501,9 +494,6 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"eof",
 								(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
-			profile_set_value(profile,section,"grid",
-								(gpointer)&ftype[i].grid,sizeof(gboolean),
-													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"limit",
 								(gpointer)&ftype[i].limit,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
@@ -513,6 +503,9 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"space",
 								(gpointer)&ftype[i].space,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
+			profile_set_value(profile,section,"gline",
+								(gpointer)&ftype[i].gline,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"mline",
 								(gpointer)&ftype[i].mline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
