@@ -34,13 +34,26 @@
 
 
 typedef struct ftype {
-	gchar *text,*ext,*fontname;
-	gboolean backup,code,crlf,eof,grid,limit,overwrite,space,mline,uline,vline;
-	gint margin,tab;
-	GdkColor color[12];
+	gchar *text,*ext;			/* O,gq */
+	gchar *fontname;			/* tHg */
+	gboolean create;			/* TRUE:VK쐬,FALSE:t@C */
+	gboolean edit;				/* TRUE:ҏWς,FALSE:ҏW */
+	gboolean code;				/* TRUE:^ũR[h\ */
+	gboolean crlf;				/* TRUE:sR[h\ */
+	gboolean eof;				/* TRUE:1Aht@C̖ɏ */
+	gboolean limit;				/* TRUE:E}[WŐ܂Ԃ */
+	gboolean overwrite;			/* TRUE:t@C㏑ƂɊmF */
+	gboolean space;				/* TRUE:Xy[XDF̎lpŕ\ */
+	gboolean gline;				/* TRUE:Obh\ */
+	gboolean mline;				/* TRUE:E}[W\ */
+	gboolean uline;				/* TRUE:^u\ */
+	gboolean vline;				/* TRUE:^uc\ */
+	gint margin;				/* E}[W̐ */
+	gint tab;					/* ^u̐ */
+	GdkColor color[12];			/* F */
 } FTYPE;
 typedef struct doing {
-	gint length;					/*  */
+	gint length;				/*  */
 	gboolean caret;
 	gchar *text;
 	GdkPoint cursor,select;
@@ -53,33 +66,41 @@ typedef struct linebuf {
 	struct linebuf *prev,*next;
 } LINEBUF;
 typedef struct textwnd {
-	gchar *file;
-	gchar *fontname;
-	gboolean create;
-	gboolean edit;
-	gboolean backup,code,crlf,eof,grid,limit,overwrite,space,mline,uline,vline;
-	gint fontsize;
-	gint fontascent;
+	gchar *file;				/* t@C */
+	gchar *fontname;			/* tHg */
+	gboolean create;			/* TRUE:VK쐬,FALSE:t@C */
+	gboolean edit;				/* TRUE:ҏWς,FALSE:ҏW */
+	gboolean code;				/* TRUE:^ũR[h\ */
+	gboolean crlf;				/* TRUE:sR[h\ */
+	gboolean eof;				/* TRUE:1Aht@C̖ɏ */
+	gboolean limit;				/* TRUE:E}[WŐ܂Ԃ */
+	gboolean overwrite;			/* TRUE:t@C㏑ƂɊmF */
+	gboolean space;				/* TRUE:Xy[XDF̎lpŕ\ */
+	gboolean gline;				/* TRUE:Obh\ */
+	gboolean mline;				/* TRUE:E}[W\ */
+	gboolean uline;				/* TRUE:^u\ */
+	gboolean vline;				/* TRUE:^uc\ */
+	gint fontsize;				/* tHg̉ */
+	gint fontascent;			/* tHg̃ANZg̍ */
 	gint margin;				/* E}[W̐ */
-	gint max;
-	gint off;
-	gint same;
+	gint max;					/* s */
+	gint off;					/* startQƂs */
+	gint same;					/* -1:dȂ,0`:ԍ */
 	gint tab;					/* ^u̐ */
 	guint timer_id;				/* XN[p^C} */
-	DOING *undo,*redo;
-	LINEBUF *start;
-	GdkIC *ic;
-	GdkICAttr *ic_attr;
+	DOING *undo,*redo;			/* ҏW */
+	LINEBUF *start;				/* `Xg */
+	GdkColor color[12];			/* F */
+	GdkFont *font;				/* tHg */
+	GdkIC *ic;					/* XIM */
+	GdkICAttr *ic_attr;			/* XIM̑ */
 	GdkPoint top;				/* EChE̐擪 */
 	GdkPoint cursor;			/* Lbg̈ʒu */
 	GdkPoint select;			/* IJnʒu,-1:IȂ */
-	GtkWidget *drawing;
-	GtkWidget *hscroll;
-	GtkWidget *vscroll;
-	GtkWidget *menu_item;
-	GdkColor color[12];
-	GdkFont *font;
-	GtkItemFactory *item_factory;	/* j[(ANZ[^[p) */
+	GtkWidget *drawing;			/* `̈ */
+	GtkWidget *hscroll;			/* XN[o[ */
+	GtkWidget *vscroll;			/* XN[o[ */
+	GtkWidget *menu_item;		/* j[̃EChE̍ */
 } TEXTWND;
 
 
@@ -109,3 +130,18 @@ extern GtkItemFactory *item_factory;	/* j[ */
 
 
 #endif
+/*
+\F
+ 0,
+ 1,wi
+ 2,Rg[R[h
+ 3,SpXy[X
+ 4,sR[h
+ 5,^u
+ 6,E}[W
+ 7,Obh
+ 8,Iꂽ
+ 9,Iꂽwi
+10,()
+11,Rg[R[h()
+*/
